<?php

namespace Luticate\Auth\Business;

use Luticate\Utils\LuBusiness;
use Luticate\Auth\DataAccess\LuticateGroupsDataAccess;
use Luticate\Auth\DBO\LuticateGroupsDbo;

class LuticateGroupsBusiness extends LuBusiness {
    protected static function getDataAccess()
    {
        return new LuticateGroupsDataAccess();
    }

    public static function checkGroupId($group_id)
    {
        if (is_null(self::getById($group_id))) {
            self::notFound("Group not found");
        }
    }

    public static function getByName($group_name)
    {
        return LuticateGroupsDataAccess::getByName($group_name);
    }

    public static function hasUser($user_id, $group_id)
    {
        return LuticateGroupsDataAccess::hasUser($user_id, $group_id);
    }

    public static function addUser($user_id, $group_id)
    {
        self::checkGroupId($group_id);
        LuticateUsersBusiness::checkUserId($user_id);
        if (self::hasUser($user_id, $group_id)) {
            return true;
        }
        return LuticateGroupsDataAccess::addUser($user_id, $group_id);
    }

    public static function delUser($user_id, $group_id)
    {
        self::checkGroupId($group_id);
        LuticateUsersBusiness::checkUserId($user_id);
        return LuticateGroupsDataAccess::delUser($user_id, $group_id);
    }

    public static function add($group_name)
    {
        $group = self::getByName($group_name);
        if (is_null($group)) {
            $group = new LuticateGroupsDbo();
            $group->setName($group_name);
            return LuticateGroupsDataAccess::addId($group);
        }
        return $group->getId();
    }

    public static function del($group_id)
    {
        self::checkGroupId($group_id);

    }
}